@@ -53,10 +53,6 @@
 #include <sys/resource.h>
 #endif
 
-#include <openssl/ssl.h>
-#include <openssl/err.h>
-#include "libclamav/crypto.h"
-
 #include "target.h"
 
 #include "libclamav/clamav.h"
@@ -80,12 +76,13 @@ short foreground = 0;
 char hostid[37];
 
 char *get_hostid(void *cbdata);
+int is_valid_hostid(void);
 
 static void help(void)
 {
     printf("\n");
     printf("                      Clam AntiVirus Daemon %s\n", get_version());
-    printf("           By The ClamAV Team: http://www.clamav.net/team\n");
+    printf("           By The ClamAV Team: http://www.clamav.net/about.html#credits\n");
     printf("           (C) 2007-2009 Sourcefire, Inc.\n\n");
 
     printf("    --help                   -h             Show this help.\n");
@@ -122,11 +119,12 @@ int main(int argc, char **argv)
     time_t currtime;
     const char *dbdir, *cfgfile;
     char *pua_cats = NULL, *pt;
-    int ret, tcpsock = 0, localsock = 0, i, min_port, max_port;
+    int ret, tcpsock = 0, localsock = 0, min_port, max_port;
     unsigned int sigs = 0;
     int *lsockets=NULL;
     unsigned int nlsockets = 0;
     unsigned int dboptions = 0;
+    unsigned int i;
 #ifdef C_LINUX
     STATBUF sb;
 #endif
@@ -141,8 +139,6 @@ int main(int argc, char **argv)
     sigaction(SIGUSR2, &sa, NULL);
 #endif
 
-    cl_initialize_crypto();
-
     if((opts = optparse(NULL, argc, argv, 1, OPT_CLAMD, 0, NULL)) == NULL) {
         mprintf("!Can't parse command line options\n");
         return 1;
@@ -582,8 +578,6 @@ int main(int argc, char **argv)
         }
 
         if(tcpsock) {
-            int *t;
-
             opt = optget(opts, "TCPAddr");
             if (opt->enabled) {
                 int breakout = 0;
@@ -676,7 +670,7 @@ int main(int argc, char **argv)
         if(!optget(opts, "Foreground")->enabled) {
 #ifdef C_BSD	    
             /* workaround for OpenBSD bug, see https://wwws.clamav.net/bugzilla/show_bug.cgi?id=885 */
-            for(ret=0;ret<nlsockets;ret++) {
+            for(ret=0;(unsigned int)ret<nlsockets;ret++) {
                 if (fcntl(lsockets[ret], F_SETFL, fcntl(lsockets[ret], F_GETFL) | O_NONBLOCK) == -1) {
                     logg("!fcntl for lsockets[] failed\n");
                     close(lsockets[ret]);
@@ -694,7 +688,7 @@ int main(int argc, char **argv)
             }
             gengine = NULL;
 #ifdef C_BSD
-            for(ret=0;ret<nlsockets;ret++) {
+            for(ret=0;(unsigned int)ret<nlsockets;ret++) {
                 if (fcntl(lsockets[ret], F_SETFL, fcntl(lsockets[ret], F_GETFL) & ~O_NONBLOCK) == -1) {
                     logg("!fcntl for lsockets[] failed\n");
                     close(lsockets[ret]);
@@ -772,6 +766,8 @@ int is_valid_hostid(void)
 
 char *get_hostid(void *cbdata)
 {
+    UNUSEDPARAM(cbdata);
+
     if (!strcmp(hostid, "none"))
         return NULL;
 
