@@ -48,10 +48,7 @@
 #include <netdb.h>
 #endif
 
-#include <openssl/ssl.h>
-#include <openssl/err.h>
-#include "libclamav/crypto.h"
-
+#include "libclamav/clamav.h"
 #include "libclamav/others.h"
 #include "shared/actions.h"
 #include "shared/output.h"
@@ -102,10 +99,9 @@ int dconnect() {
         memset(&hints, 0x00, sizeof(struct addrinfo));
         hints.ai_family = AF_UNSPEC;
         hints.ai_socktype = SOCK_STREAM;
-        hints.ai_flags = AI_PASSIVE;
 
         if ((res = getaddrinfo(ipaddr, port, &hints, &info))) {
-            logg("!Could not lookup %s: %s\n", opt->strarg, gai_strerror(res));
+            logg("!Could not lookup %s: %s\n", ipaddr ? ipaddr : "", gai_strerror(res));
             opt = opt->nextarg;
             continue;
         }
@@ -239,6 +235,7 @@ static int chkpath(const char *path)
 
 static int ftw_chkpath(const char *path, struct cli_ftw_cbdata *data)
 {
+    UNUSEDPARAM(data);
     return chkpath(path);
 }
 
@@ -381,6 +378,8 @@ static int serial_callback(STATBUF *sb, char *filename, const char *path, enum c
     int sockd, ret;
     const char *f = filename;
 
+    UNUSEDPARAM(sb);
+
     if(chkpath(path))
 	return CL_SUCCESS;
     c->files++;
@@ -535,6 +534,8 @@ static int parallel_callback(STATBUF *sb, char *filename, const char *path, enum
     struct SCANID *cid;
     int res = CL_CLEAN;
 
+    UNUSEDPARAM(sb);
+
     if(chkpath(path))
 	return CL_SUCCESS;
     c->files++;
