@@ -119,6 +119,8 @@ static const struct ftmap_s {
     { "CL_TYPE_OOXML_XL",	CL_TYPE_OOXML_XL     	},
     { "CL_TYPE_INTERNAL",	CL_TYPE_INTERNAL     	},
     { "CL_TYPE_XDP",        CL_TYPE_XDP             },
+    { "CL_TYPE_XML_WORD",   CL_TYPE_XML_WORD        },
+    { "CL_TYPE_XML_XL",     CL_TYPE_XML_XL          },
     { NULL,			CL_TYPE_IGNORED		}
 };
 
