@@ -108,6 +108,8 @@ typedef enum {
     CL_TYPE_GPT,
     CL_TYPE_APM,
     CL_TYPE_XDP,
+    CL_TYPE_XML_WORD,
+    CL_TYPE_XML_XL,
     CL_TYPE_IGNORED /* please don't add anything below */
 } cli_file_t;
 
