@@ -23,10 +23,7 @@
 #include "clamav-config.h"
 #endif
 
-#include <openssl/ssl.h>
-#include <openssl/err.h>
-#include "libclamav/crypto.h"
-
+#include "clamav.h"
 #include "filtering.h"
 #include "matcher-ac.h"
 #include <string.h>
@@ -193,6 +190,8 @@ int filter_add_static(struct filter *m, const unsigned char *pattern, unsigned l
 	uint32_t best = 0xffffffff;
 	uint8_t best_pos = 0;
 
+    UNUSEDPARAM(name);
+
 	cli_perf_log_count(TRIE_ORIG_LEN, len > 8 ? 8 : len);
 	/* TODO: choose best among MAXCHOICES */
 	/* cut length */
@@ -285,15 +284,6 @@ static inline unsigned char spec_ith_char(const struct char_spec *spec, unsigned
 	return i;
 }
 
-static const struct char_spec full_range = {NULL, 0,0xff,1,0};
-
-static inline int spec_is_fullrange(const struct char_spec *spec0, const struct char_spec *spec1)
-{
-	return !memcmp(spec0, &full_range, sizeof(full_range)) &&
-	       !memcmp(spec1, &full_range, sizeof(full_range));
-}
-
-
 #ifndef MIN
 #define MIN(a,b) ((a) < (b) ? (a) : (b))
 #endif
@@ -699,43 +689,6 @@ int  filter_add_acpatt(struct filter *m, const struct cli_ac_patt *pat)
 	return j+2;
 }
 
-static const struct match_len_info {
-	uint8_t shortest;
-	uint8_t longest;
-} match_len[256] = {
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{5,9},
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{6,9},
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{5,9},
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{7,9},
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{5,9},
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{6,9},
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{5,9},
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{8,9},
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{5,9},
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{6,9},
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{5,9},
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{7,9},
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{5,9},
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{6,9},
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{5,9},
-	{2,9},{3,9},{2,9},{4,9},{2,9},{3,9},{2,9},{9,9},
-	{2,8},{3,8},{2,8},{4,8},{2,8},{3,8},{2,8},{5,8},
-	{2,8},{3,8},{2,8},{4,8},{2,8},{3,8},{2,8},{6,8},
-	{2,8},{3,8},{2,8},{4,8},{2,8},{3,8},{2,8},{5,8},
-	{2,8},{3,8},{2,8},{4,8},{2,8},{3,8},{2,8},{7,8},
-	{2,8},{3,8},{2,8},{4,8},{2,8},{3,8},{2,8},{5,8},
-	{2,8},{3,8},{2,8},{4,8},{2,8},{3,8},{2,8},{6,8},
-	{2,8},{3,8},{2,8},{4,8},{2,8},{3,8},{2,8},{5,8},
-	{2,8},{3,8},{2,8},{4,8},{2,8},{3,8},{2,8},{8,8},
-	{2,7},{3,7},{2,7},{4,7},{2,7},{3,7},{2,7},{5,7},
-	{2,7},{3,7},{2,7},{4,7},{2,7},{3,7},{2,7},{6,7},
-	{2,7},{3,7},{2,7},{4,7},{2,7},{3,7},{2,7},{5,7},
-	{2,7},{3,7},{2,7},{4,7},{2,7},{3,7},{2,7},{7,7},
-	{2,6},{3,6},{2,6},{4,6},{2,6},{3,6},{2,6},{5,6},
-	{2,6},{3,6},{2,6},{4,6},{2,6},{3,6},{2,6},{6,6},
-	{2,5},{3,5},{2,5},{4,5},{2,5},{3,5},{2,5},{5,5},
-	{2,4},{3,4},{2,4},{4,4},{2,3},{3,3},{2,2},{0,0}
-};
 /* state 11110011 means that we may have a match of length min 4, max 5 */
 
 __hot__ int filter_search_ext(const struct filter *m, const unsigned char *data, unsigned long len, struct filter_match_info *inf)
