@@ -22,17 +22,17 @@
 #include "clamav-config.h"
 #endif
 
-#include <openssl/ssl.h>
-#include <openssl/err.h>
-#include "libclamav/crypto.h"
-
+#include "clamav.h"
 #include "7z/XzCrc64.h"
 #include "xz_iface.h"
 
-void *__xz_wrap_alloc(void *unused, size_t size) { 
+void *__xz_wrap_alloc(void *unused, size_t size);
+void __xz_wrap_free(void *unused, void *freeme);
+
+void *__xz_wrap_alloc(void *unused, size_t size) {
+    UNUSEDPARAM(unused);
     if(!size || size > CLI_MAX_ALLOCATION)
 	return NULL;
-    unused = unused;
     if(!size || size > CLI_MAX_ALLOCATION) {
 	cli_dbgmsg("xz_iface: Attempt to allocate %lu bytes exceeds CLI_MAX_ALLOCATION.\n",
                    (unsigned long int) size);
@@ -41,7 +41,7 @@ void *__xz_wrap_alloc(void *unused, size_t size) {
     return cli_malloc(size);
 }
 void __xz_wrap_free(void *unused, void *freeme) {
-    unused = unused;
+    UNUSEDPARAM(unused);
     free(freeme);
 }
 
@@ -75,7 +75,7 @@ int cli_XzDecode(struct CLI_XZ *XZ) {
         return XZ_STREAM_END;
     if (XZ->status == CODER_STATUS_NOT_FINISHED && XZ->avail_out == 0)
         return XZ_RESULT_OK;
-    if (res != SZ_OK)
+    if (((inbytes == 0) && (outbytes == 0)) || res != SZ_OK)
 	return XZ_RESULT_DATA_ERROR;
     return XZ_RESULT_OK;
 }
