@@ -52,10 +52,6 @@
 #include <termios.h>
 #endif
 
-#include <openssl/ssl.h>
-#include <openssl/err.h>
-#include "libclamav/crypto.h"
-
 #include "vba.h"
 
 #include "shared/output.h"
@@ -307,16 +303,13 @@ static char *getdsig(const char *host, const char *user, const unsigned char *da
 	    return NULL;
 	}
 #endif
-	if(scanf("%as", &pt) == EOF || !pt) {
+	if(scanf("%30s", pass) == EOF) {
 	    mprintf("!getdsig: Can't get password\n");
 #ifdef HAVE_TERMIOS_H
 	    tcsetattr(0, TCSAFLUSH, &old);
 #endif
 	    return NULL;
 	}
-	strncpy(pass, pt, sizeof(pass));
-	pass[sizeof(pass)-1]='\0';
-	free(pt);
 
 #ifdef HAVE_TERMIOS_H
 	if(tcsetattr(0, TCSAFLUSH, &old)) {
@@ -380,7 +373,7 @@ static char *getdsig(const char *host, const char *user, const unsigned char *da
 	    closesocket(sockd);
 	    return NULL;
 	} else {
-	    mprintf("Signature received (length = %lu)\n", strlen(buff) - 10);
+	    mprintf("Signature received (length = %lu)\n", (unsigned long)strlen(buff) - 10);
 	}
     } else {
 	mprintf("!getdsig: Communication error with remote server\n");
@@ -719,6 +712,7 @@ static int build(const struct optstruct *opts)
 			dblist2 = (char **) realloc(dblist2, (dblist2cnt + 1) * sizeof(char *));
 			if(!dblist2) { /* dblist2 leaked but we don't really care */
 			    mprintf("!build: Memory allocation error\n");
+                            closedir(dd);
 			    return -1;
 			}
 			dblist2[dblist2cnt] = strdup(dent->d_name);
@@ -852,13 +846,11 @@ static int build(const struct optstruct *opts)
 	builder[sizeof(builder)-1]='\0';
     } else {
 	mprintf("Builder name: ");
-	if(scanf("%as", &pt) == EOF || !pt) {
+	if(scanf("%32s", builder) == EOF) {
 	    mprintf("!build: Can't get builder name\n");
+	    free(dblist2);
 	    return -1;
 	}
-	strncpy(builder, pt, sizeof(builder));
-	builder[sizeof(builder)-1]='\0';
-	free(pt);
     }
 
     /* add builder */
@@ -1133,6 +1125,11 @@ static int unpack(const struct optstruct *opts)
 	name[sizeof(name)-1]='\0';
     }
 
+    if (cl_cvdverify(name) != CL_SUCCESS) {
+        mprintf("!unpack: %s is not a valid CVD\n", name);
+        return -1;
+    }
+
     if(cli_cvdunpack(name, ".") == -1) {
 	mprintf("!unpack: Can't unpack file %s\n", name);
 	return -1;
@@ -2995,8 +2992,6 @@ int main(int argc, char **argv)
     if(check_flevel())
 	exit(1);
 
-    cl_initialize_crypto();
-
     if((ret = cl_init(CL_INIT_DEFAULT)) != CL_SUCCESS) {
 	mprintf("!Can't initialize libclamav: %s\n", cl_strerror(ret));
 	return -1;
